@@ -81,11 +81,11 @@
 #' @param call_info A list of call information and parameters. If not provided,
 #' it will be generated from the function call. Defaults to `NULL`
 #'
-#' @return An `eyeris` object with a new column in `timeseries`:
+#' @return An `eyeris` object with a new column in `time series`:
 #' `pupil_raw_{...}_detransient`
 #'
 #' @seealso [eyeris::glassbox()] for the recommended way to run this step as
-#' part of the full eyeris glassbox preprocessing pipeline.
+#' part of the full `eyeris` glassbox preprocessing pipeline.
 #'
 #' @examples
 #' demo_data <- eyelink_asc_demo_dataset()
@@ -198,10 +198,10 @@ detransient_pupil <- function(x, prev_op, n, mad_thresh) {
     mad_val <- median(abs(pupil_speed - median_speed), na.rm = TRUE)
     mad_thresh <- median_speed + (n * mad_val)
   } else if (is.numeric(mad_thresh)) {
-    alert("warning", "[WARN] Using user supplied `mad_thresh`... skipping calculation")
+    log_warn("Using user supplied `mad_thresh`... skipping calculation")
     mad_val <- 0
   } else {
-    cli::cli_abort("[EXIT] `mad_thresh` must either be `NULL` or numeric.")
+    log_error("`mad_thresh` must either be `NULL` or numeric.")
   }
 
   # validate `mad_val` != 0: unrealistic outcome for real data
@@ -248,7 +248,7 @@ detransient_pupil <- function(x, prev_op, n, mad_thresh) {
       "RISK.\n\n\n"
     ))
 
-    cli::cli_abort("[EXIT] Computed property `mad_val` == 0!")
+    log_error("Computed property `mad_val` == 0!")
   }
 
   # handle case where mad_val is NA (all pupil data is NA)
