@@ -12,7 +12,7 @@
 #' @keywords internal
 error_handler <- function(e, e_class) {
   if (inherits(e, e_class)) {
-    cli::cli_alert_danger(e$message)
+    log_error(e$message)
   } else {
     stop(e)
   }
